==> wbxml-0.1.0.tgz: wbxml-0.1.0/wbxml.c <==
/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2006 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Mikael Johansson <mikael AT synd DOT info>                   |
  +----------------------------------------------------------------------+
*/

/* $Id: wbxml.c,v 0.0.0.0.0.1 2006/01/01 13:46:51 mikl Exp $ */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "ext/standard/info.h"
#include "php_wbxml.h"

#undef HAVE_LIBXML
#include "wbxml.h"

/* {{{ wbxml_functions[]
 */
zend_function_entry wbxml_functions[] = {
	PHP_FE(wbxml_encode,	NULL)
	PHP_FE(wbxml_decode,	NULL)
	{NULL, NULL, NULL}
};
/* }}} */

/* {{{ wbxml_module_entry
 */
zend_module_entry wbxml_module_entry = {
#if ZEND_MODULE_API_NO >= 20010901
	STANDARD_MODULE_HEADER,
#endif
	"wbxml",
	wbxml_functions,
	PHP_MINIT(wbxml),
	PHP_MSHUTDOWN(wbxml),
	NULL,					/* Replace with NULL if there's nothing to do at request start */
	NULL,					/* Replace with NULL if there's nothing to do at request end */
	PHP_MINFO(wbxml),
#if ZEND_MODULE_API_NO >= 20010901
	NO_VERSION_YET,			/* Replace with version number for your extension */
#endif
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_WBXML
ZEND_GET_MODULE(wbxml)
#endif

/* {{{ PHP_MINIT_FUNCTION
 */
PHP_MINIT_FUNCTION(wbxml)
{
	/* If you have INI entries, uncomment these lines
	ZEND_INIT_MODULE_GLOBALS(wbxml, php_wbxml_init_globals, NULL);
	REGISTER_INI_ENTRIES();
	*/

	REGISTER_LONG_CONSTANT("WBXML_VERSION_10",			WBXML_VERSION_10,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_VERSION_11",			WBXML_VERSION_11,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_VERSION_12",			WBXML_VERSION_12,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_VERSION_13",			WBXML_VERSION_13,			CONST_CS | CONST_PERSISTENT);

	REGISTER_LONG_CONSTANT("WBXML_LANG_UNKNOWN",		WBXML_LANG_UNKNOWN,			CONST_CS | CONST_PERSISTENT);

    /* WAP */
#if defined( WBXML_SUPPORT_WML )
	REGISTER_LONG_CONSTANT("WBXML_LANG_WML10",			WBXML_LANG_WML10,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WML11",			WBXML_LANG_WML11,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WML12",			WBXML_LANG_WML12,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WML13",			WBXML_LANG_WML13,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_WML */

#if defined( WBXML_SUPPORT_WTA )
	REGISTER_LONG_CONSTANT("WBXML_LANG_WTA10",			WBXML_LANG_WTA10,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WTAWML12",		WBXML_LANG_WTAWML12,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_CHANNEL11",		WBXML_LANG_CHANNEL11,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_CHANNEL12",		WBXML_LANG_CHANNEL12,		CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_WTA */

#if defined( WBXML_SUPPORT_SI )
	REGISTER_LONG_CONSTANT("WBXML_LANG_SI10",			WBXML_LANG_SI10,			CONST_CS | CONST_PERSISTENT);
    WBXML_LANG_SI10,            /**< SI 1.0 */
#endif /* WBXML_SUPPORT_SI */

#if defined( WBXML_SUPPORT_SL )
	REGISTER_LONG_CONSTANT("WBXML_LANG_SL10",			WBXML_LANG_SL10,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_SL */

#if defined( WBXML_SUPPORT_CO )
	REGISTER_LONG_CONSTANT("WBXML_LANG_CO10",			WBXML_LANG_CO10,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_CO */

#if defined( WBXML_SUPPORT_PROV )
	REGISTER_LONG_CONSTANT("WBXML_LANG_PROV10",			WBXML_LANG_PROV10,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_PROV */

#if defined( WBXML_SUPPORT_EMN )
	REGISTER_LONG_CONSTANT("WBXML_LANG_EMN10",			WBXML_LANG_EMN10,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_EMN */

#if defined( WBXML_SUPPORT_DRMREL )
	REGISTER_LONG_CONSTANT("WBXML_LANG_DRMREL10",		WBXML_LANG_DRMREL10,		CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_DRMREL */

#if defined( WBXML_SUPPORT_OTA_SETTINGS )
    /* Ericsson / Nokia OTA Settings v7.0 */
	REGISTER_LONG_CONSTANT("WBXML_LANG_OTA_SETTINGS",	WBXML_LANG_OTA_SETTINGS,	CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_OTA_SETTINGS */

    /* SyncML */
#if defined( WBXML_SUPPORT_SYNCML )
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_SYNCML10",WBXML_LANG_SYNCML_SYNCML10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_DEVINF10",WBXML_LANG_SYNCML_DEVINF10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_METINF10",WBXML_LANG_SYNCML_METINF10,	CONST_CS | CONST_PERSISTENT);

	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_SYNCML11",WBXML_LANG_SYNCML_SYNCML10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_DEVINF11",WBXML_LANG_SYNCML_DEVINF10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_METINF11",WBXML_LANG_SYNCML_METINF10,	CONST_CS | CONST_PERSISTENT);

	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_SYNCML12",WBXML_LANG_SYNCML_SYNCML10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_DEVINF12",WBXML_LANG_SYNCML_DEVINF10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_METINF12",WBXML_LANG_SYNCML_METINF10,	CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_SYNCML */

    /* Wireless-Village */
#if defined( WBXML_SUPPORT_WV )
	REGISTER_LONG_CONSTANT("WBXML_LANG_WV_CSP11",		WBXML_LANG_WV_CSP11,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WV_CSP12",		WBXML_LANG_WV_CSP12,		CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_WV */

    /* Microsoft AirSync */
#if defined( WBXML_SUPPORT_AIRSYNC )
	REGISTER_LONG_CONSTANT("WBXML_LANG_AIRSYNC",		WBXML_LANG_AIRSYNC,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_AIRSYNC */

	REGISTER_LONG_CONSTANT("WBXML_GEN_XML_COMPACT",		WBXML_GEN_XML_COMPACT,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_GEN_XML_INDENT",		WBXML_GEN_XML_INDENT,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_GEN_XML_CANONICAL",	WBXML_GEN_XML_CANONICAL,	CONST_CS | CONST_PERSISTENT);

	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION
 */
PHP_MSHUTDOWN_FUNCTION(wbxml)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION
 */
PHP_MINFO_FUNCTION(wbxml)
{
	php_info_print_table_start();
	php_info_print_table_header(2, "wbxml support", "enabled");
	php_info_print_table_end();
}
/* }}} */

/* {{{ proto string wbxml_encode(string xml [, long wbxml_version [, bool use_strtbl [, bool keep_ignorable_ws ] ] ])
   Encode an XML document into WBXML */
PHP_FUNCTION(wbxml_encode)
{
	char *xml;
	int xml_len;
	long wbxml_version = WBXML_VERSION_12;
	zend_bool use_strtbl = 1, keep_ignorable_ws = 0;

	WB_UTINY *wbxml = NULL;
	WB_LONG wbxml_len = 0;
	WBXMLConvXML2WBXMLParams params;
	WBXMLError result = WBXML_OK;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|lbb", &xml, &xml_len, &wbxml_version, &use_strtbl, &keep_ignorable_ws) == FAILURE) {
		return;
	}

	params.wbxml_version = wbxml_version;
	params.keep_ignorable_ws = keep_ignorable_ws;
	params.use_strtbl = use_strtbl;

	if ((result = wbxml_conv_xml2wbxml(xml, &wbxml, &wbxml_len, &params)) == WBXML_OK) {
		RETVAL_STRINGL(wbxml, wbxml_len, 1);
	}
	else {
		zend_error(E_WARNING, (const char *)wbxml_errors_string(result));
		RETVAL_NULL();
	}

	wbxml_free(wbxml);
}
/* }}} */

/* {{{ proto string wbxml_decode(string wbxml [, int gen_type [, int lang [, int indent [, bool keep_ignorable_ws ] ] ] ])
   Decodes an WBXML document into XML */
PHP_FUNCTION(wbxml_decode)
{
	char *wbxml;
	int wbxml_len;
	long gen_type = WBXML_GEN_XML_INDENT, lang = WBXML_LANG_UNKNOWN, indent = 0;
	zend_bool keep_ignorable_ws = 0;

	WB_UTINY *xml = NULL;
	WBXMLConvWBXML2XMLParams params;
	WBXMLError result = WBXML_OK;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|lllb", &wbxml, &wbxml_len, &gen_type, &lang, &indent, &keep_ignorable_ws) == FAILURE) {
		return;
	}

	params.gen_type = gen_type;
	params.lang = lang;
	params.indent = indent;
	params.keep_ignorable_ws = keep_ignorable_ws;

	if ((result = wbxml_conv_wbxml2xml(wbxml, wbxml_len, &xml, &params)) == WBXML_OK) {
		RETVAL_STRING(xml, 1);
	}
	else {
		zend_error(E_WARNING, (const char *)wbxml_errors_string(result));
		RETVAL_NULL();
	}

	wbxml_free(xml);
}
/* }}} */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */

==> wbxml-1.0.3.tgz: wbxml-1.0.3/wbxml.c <==
/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2006 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Mikael Johansson <mikael AT synd DOT info>                   |
  +----------------------------------------------------------------------+
*/

/* $Id: wbxml.c,v 1.4 2008/03/31 10:24:59 sfox Exp $ */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "ext/standard/info.h"
#include "php_wbxml.h"

#undef HAVE_LIBXML
#include "wbxml.h"

/* {{{ wbxml_functions[]
 */
zend_function_entry wbxml_functions[] = {
	PHP_FE(wbxml_encode,	NULL)
	PHP_FE(wbxml_decode,	NULL)
	{NULL, NULL, NULL}
};
/* }}} */

/* {{{ wbxml_module_entry
 */
zend_module_entry wbxml_module_entry = {
#if ZEND_MODULE_API_NO >= 20010901
	STANDARD_MODULE_HEADER,
#endif
	"wbxml",
	wbxml_functions,
	PHP_MINIT(wbxml),
	PHP_MSHUTDOWN(wbxml),
	NULL,					/* Replace with NULL if there's nothing to do at request start */
	NULL,					/* Replace with NULL if there's nothing to do at request end */
	PHP_MINFO(wbxml),
#if ZEND_MODULE_API_NO >= 20010901
	PHP_WBXML_VERSION,
#endif
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_WBXML
ZEND_GET_MODULE(wbxml)
#endif

/* {{{ PHP_MINIT_FUNCTION
 */
PHP_MINIT_FUNCTION(wbxml)
{
	/* If you have INI entries, uncomment these lines
	ZEND_INIT_MODULE_GLOBALS(wbxml, php_wbxml_init_globals, NULL);
	REGISTER_INI_ENTRIES();
	*/

	REGISTER_LONG_CONSTANT("WBXML_VERSION_10",			WBXML_VERSION_10,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_VERSION_11",			WBXML_VERSION_11,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_VERSION_12",			WBXML_VERSION_12,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_VERSION_13",			WBXML_VERSION_13,			CONST_CS | CONST_PERSISTENT);

	REGISTER_LONG_CONSTANT("WBXML_LANG_UNKNOWN",		WBXML_LANG_UNKNOWN,			CONST_CS | CONST_PERSISTENT);

    /* WAP */
#if defined( WBXML_SUPPORT_WML )
	REGISTER_LONG_CONSTANT("WBXML_LANG_WML10",			WBXML_LANG_WML10,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WML11",			WBXML_LANG_WML11,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WML12",			WBXML_LANG_WML12,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WML13",			WBXML_LANG_WML13,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_WML */

#if defined( WBXML_SUPPORT_WTA )
	REGISTER_LONG_CONSTANT("WBXML_LANG_WTA10",			WBXML_LANG_WTA10,			CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WTAWML12",		WBXML_LANG_WTAWML12,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_CHANNEL11",		WBXML_LANG_CHANNEL11,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_CHANNEL12",		WBXML_LANG_CHANNEL12,		CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_WTA */

#if defined( WBXML_SUPPORT_SI )
	REGISTER_LONG_CONSTANT("WBXML_LANG_SI10",			WBXML_LANG_SI10,			CONST_CS | CONST_PERSISTENT);
    WBXML_LANG_SI10,            /**< SI 1.0 */
#endif /* WBXML_SUPPORT_SI */

#if defined( WBXML_SUPPORT_SL )
	REGISTER_LONG_CONSTANT("WBXML_LANG_SL10",			WBXML_LANG_SL10,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_SL */

#if defined( WBXML_SUPPORT_CO )
	REGISTER_LONG_CONSTANT("WBXML_LANG_CO10",			WBXML_LANG_CO10,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_CO */

#if defined( WBXML_SUPPORT_PROV )
	REGISTER_LONG_CONSTANT("WBXML_LANG_PROV10",			WBXML_LANG_PROV10,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_PROV */

#if defined( WBXML_SUPPORT_EMN )
	REGISTER_LONG_CONSTANT("WBXML_LANG_EMN10",			WBXML_LANG_EMN10,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_EMN */

#if defined( WBXML_SUPPORT_DRMREL )
	REGISTER_LONG_CONSTANT("WBXML_LANG_DRMREL10",		WBXML_LANG_DRMREL10,		CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_DRMREL */

#if defined( WBXML_SUPPORT_OTA_SETTINGS )
    /* Ericsson / Nokia OTA Settings v7.0 */
	REGISTER_LONG_CONSTANT("WBXML_LANG_OTA_SETTINGS",	WBXML_LANG_OTA_SETTINGS,	CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_OTA_SETTINGS */

    /* SyncML */
#if defined( WBXML_SUPPORT_SYNCML )
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_SYNCML10",WBXML_LANG_SYNCML_SYNCML10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_DEVINF10",WBXML_LANG_SYNCML_DEVINF10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_METINF10",WBXML_LANG_SYNCML_METINF10,	CONST_CS | CONST_PERSISTENT);

	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_SYNCML11",WBXML_LANG_SYNCML_SYNCML10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_DEVINF11",WBXML_LANG_SYNCML_DEVINF10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_METINF11",WBXML_LANG_SYNCML_METINF10,	CONST_CS | CONST_PERSISTENT);

	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_SYNCML12",WBXML_LANG_SYNCML_SYNCML10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_DEVINF12",WBXML_LANG_SYNCML_DEVINF10,	CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_SYNCML_METINF12",WBXML_LANG_SYNCML_METINF10,	CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_SYNCML */

    /* Wireless-Village */
#if defined( WBXML_SUPPORT_WV )
	REGISTER_LONG_CONSTANT("WBXML_LANG_WV_CSP11",		WBXML_LANG_WV_CSP11,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_LANG_WV_CSP12",		WBXML_LANG_WV_CSP12,		CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_WV */

    /* Microsoft AirSync */
#if defined( WBXML_SUPPORT_AIRSYNC )
	REGISTER_LONG_CONSTANT("WBXML_LANG_AIRSYNC",		WBXML_LANG_AIRSYNC,			CONST_CS | CONST_PERSISTENT);
#endif /* WBXML_SUPPORT_AIRSYNC */

	REGISTER_LONG_CONSTANT("WBXML_GEN_XML_COMPACT",		WBXML_GEN_XML_COMPACT,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_GEN_XML_INDENT",		WBXML_GEN_XML_INDENT,		CONST_CS | CONST_PERSISTENT);
	REGISTER_LONG_CONSTANT("WBXML_GEN_XML_CANONICAL",	WBXML_GEN_XML_CANONICAL,	CONST_CS | CONST_PERSISTENT);

	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION
 */
PHP_MSHUTDOWN_FUNCTION(wbxml)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION
 */
PHP_MINFO_FUNCTION(wbxml)
{
	php_info_print_table_start();
	php_info_print_table_header(2, "WBXML support", "enabled");
	php_info_print_table_row(2, "extension version", PHP_WBXML_VERSION);
	php_info_print_table_row(2, "libwbxml version", WBXML_LIB_VERSION);
	php_info_print_table_end();
}
/* }}} */

/* {{{ proto string wbxml_encode(string xml [, int wbxml_version [, bool use_strtbl [, bool keep_ignorable_ws ] ] ])
   Encode an XML document into WBXML */
PHP_FUNCTION(wbxml_encode)
{
	char *xml;
	int xml_len;
	long wbxml_version = WBXML_VERSION_12;
	zend_bool use_strtbl = 1, keep_ignorable_ws = 0;

	WB_UTINY *wbxml = NULL;
	WB_LONG wbxml_len = 0;
	WBXMLConvXML2WBXMLParams params;
	WBXMLError result = WBXML_OK;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|lbb", &xml, &xml_len, &wbxml_version, &use_strtbl, &keep_ignorable_ws) == FAILURE) {
		return;
	}

	params.wbxml_version = wbxml_version;
	params.keep_ignorable_ws = keep_ignorable_ws;
	params.use_strtbl = use_strtbl;

	if ((result = wbxml_conv_xml2wbxml(xml, &wbxml, &wbxml_len, &params)) == WBXML_OK) {
		RETVAL_STRINGL(wbxml, wbxml_len, 1);
	}
	else {
		zend_error(E_WARNING, (const char *)wbxml_errors_string(result));
		RETVAL_NULL();
	}

	wbxml_free(wbxml);
}
/* }}} */

/* {{{ proto string wbxml_decode(string wbxml [, int gen_type [, int lang [, int indent [, bool keep_ignorable_ws ] ] ] ])
   Decode a WBXML document into XML */
PHP_FUNCTION(wbxml_decode)
{
	char *wbxml;
	int wbxml_len;
	long gen_type = WBXML_GEN_XML_INDENT, lang = WBXML_LANG_UNKNOWN, indent = 0;
	zend_bool keep_ignorable_ws = 0;

	WB_UTINY *xml = NULL;
	WBXMLConvWBXML2XMLParams params;
	WBXMLError result = WBXML_OK;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|lllb", &wbxml, &wbxml_len, &gen_type, &lang, &indent, &keep_ignorable_ws) == FAILURE) {
		return;
	}

	params.gen_type = gen_type;
	params.lang = lang;
	params.indent = indent;
	params.keep_ignorable_ws = keep_ignorable_ws;

	if ((result = wbxml_conv_wbxml2xml(wbxml, wbxml_len, &xml, &params)) == WBXML_OK) {
		RETVAL_STRING(xml, 1);
	}
	else {
		zend_error(E_WARNING, (const char *)wbxml_errors_string(result));
		RETVAL_NULL();
	}

	wbxml_free(xml);
}
/* }}} */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
